@@ -3,13 +3,15 @@
 #       * Miotte Julien <j.m@majerti.fr>;
 #       * TJEBBES Gaston <g.t@majerti.fr>
 """
-    Provide common tools for string handling
+Provide common tools for string handling
 """
-import re
-from unidecode import unidecode
+
 import random
+import re
 from string import ascii_lowercase
 
+from unidecode import unidecode
+
 
 def force_ascii(value):
     """
@@ -29,7 +31,7 @@ def force_utf8(value):
     :param str value:
     :rtype: bytes
     """
-    return force_encoding(value, 'utf-8')
+    return force_encoding(value, "utf-8")
 
 
 def force_encoding(value, encoding):
