@@ -3,10 +3,11 @@
 #       * Miotte Julien <j.m@majerti.fr>;
 #       * TJEBBES Gaston <g.t@majerti.fr>
 """
-    Csv exporter for sqlalchemy datas
+Csv exporter for sqlalchemy datas
 
-    uses the sqlalchemy info attr to retrieve meta datas about the columns
+uses the sqlalchemy info attr to retrieve meta datas about the columns
 """
+
 import csv
 import io
 
@@ -15,7 +16,6 @@ from sqla_inspect.export import (
     SqlaExporter,
 )
 
-
 CSV_DELIMITER = ";"
 CSV_QUOTECHAR = '"'
 
@@ -32,6 +32,7 @@ class CsvWriter(object):
 
     delimiter = CSV_DELIMITER
     quotechar = CSV_QUOTECHAR
+    quoting = csv.QUOTE_ALL
 
     def __init__(self, **kw):
         self.options = kw
@@ -59,7 +60,7 @@ class CsvWriter(object):
             extrasaction="ignore",
             delimiter=self.delimiter,
             quotechar=self.quotechar,
-            quoting=csv.QUOTE_ALL,
+            quoting=self.quoting,
         )
         outfile.writeheader()
         _datas = getattr(self, "_datas", ())
